@@ -164,7 +164,6 @@ VideoWindow::VideoWindow( QWidget *parent )
 
 VideoWindow::~VideoWindow()
 {
-
     eject();
     KConfigGroup config = KGlobal::config()->group( "General" );
     config.writeEntry( "Volume", static_cast<double>( m_aOutput->volume() ) );
@@ -194,7 +193,6 @@ VideoWindow::init()
 bool
 VideoWindow::load( const KUrl &url )
 {
-
     QApplication::setOverrideCursor( Qt::WaitCursor );
 
     eject();
@@ -235,7 +233,6 @@ VideoWindow::resume()
     return true;
 }
 
-
 bool
 VideoWindow::playDvd()
 {
@@ -719,6 +716,18 @@ VideoWindow::tenSecondsForward()
     relativeSeek( 10000 );
 }
 
+void
+VideoWindow::increaseVolume()
+{
+    m_aOutput->setVolume(qMin(qreal(1.0), volume() + 0.10));
+}
+
+void
+VideoWindow::decreaseVolume()
+{
+    m_aOutput->setVolume(qMax(qreal(0.0), volume() - 0.10));
+}
+
 ///////////
 ///Protected
 ///////////
